@@ -45,6 +45,9 @@ class SensorDeviceClass(BaseDeviceClass):
     # energy (Wh, kWh, MWh)
     ENERGY = "energy"
 
+    # Volume flow rate (m3 per hour)
+    VOLUME_FLOW_RATE = "volume_flow_rate"
+
     # formaldehyde (µg/m³)
     FORMALDEHYDE = "formaldehyde"
 
@@ -87,6 +90,9 @@ class SensorDeviceClass(BaseDeviceClass):
     # Amount of O3 (µg/m³)
     OZONE = "ozone"
 
+    # Packet id (no unit)
+    PACKET_ID = "packet_id"
+
     # Particulate matter <= 0.1 μm (µg/m³)
     PM1 = "pm1"
 
@@ -150,6 +156,9 @@ class SensorDeviceClass(BaseDeviceClass):
     # voltage (V)
     VOLTAGE = "voltage"
 
+    # Volume (ml, L)
+    VOLUME = "volume"
+
     # Volume dispensed (L)
     VOLUME_DISPENSED = "volume_dispensed"
 
